==> zio-aws-lexmodelsv2_3-5.17.158.2-sources.jar: zio/aws/lexmodelsv2/model/GrammarSlotTypeSetting.scala <==
package zio.aws.lexmodelsv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GrammarSlotTypeSetting(
    source: Option[zio.aws.lexmodelsv2.model.GrammarSlotTypeSource] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting = {
    import GrammarSlotTypeSetting.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
      .builder()
      .optionallyWith(source.map(value => value.buildAwsValue()))(_.source)
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.ReadOnly =
    zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.wrap(buildAwsValue())
}
object GrammarSlotTypeSetting {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting =
      zio.aws.lexmodelsv2.model
        .GrammarSlotTypeSetting(source.map(value => value.asEditable))
    def source: Option[zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.ReadOnly]
    def getSource: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.ReadOnly
    ] = AwsError.unwrapOptionField("source", source)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
  ) extends zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.ReadOnly {
    override val source
        : Option[zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.ReadOnly] =
      scala
        .Option(impl.source())
        .map(value =>
          zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
  ): zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-lexmodelsv2_3-5.19.12.1-sources.jar: zio/aws/lexmodelsv2/model/GrammarSlotTypeSetting.scala <==
package zio.aws.lexmodelsv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GrammarSlotTypeSetting(
    source: Optional[zio.aws.lexmodelsv2.model.GrammarSlotTypeSource] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting = {
    import GrammarSlotTypeSetting.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
      .builder()
      .optionallyWith(source.map(value => value.buildAwsValue()))(_.source)
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.ReadOnly =
    zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.wrap(buildAwsValue())
}
object GrammarSlotTypeSetting {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting =
      zio.aws.lexmodelsv2.model
        .GrammarSlotTypeSetting(source.map(value => value.asEditable))
    def source
        : Optional[zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.ReadOnly]
    def getSource: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.ReadOnly
    ] = AwsError.unwrapOptionField("source", source)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
  ) extends zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.ReadOnly {
    override val source
        : Optional[zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.source())
        .map(value =>
          zio.aws.lexmodelsv2.model.GrammarSlotTypeSource.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.GrammarSlotTypeSetting
  ): zio.aws.lexmodelsv2.model.GrammarSlotTypeSetting.ReadOnly = new Wrapper(
    impl
  )
}
